pub struct RateSelectionOffloadExtension {
pub supported: Option<bool>,
}Expand description
Indicates where and how rate selection logic is orchestrated. See IEEE 802.11-2016 10.7. This is a MAC sublayer extension, expected to be used for softmac only.
Fields
supported: Option<bool>Trait Implementations
Sourceimpl Clone for RateSelectionOffloadExtension
impl Clone for RateSelectionOffloadExtension
Sourcefn clone(&self) -> RateSelectionOffloadExtension
fn clone(&self) -> RateSelectionOffloadExtension
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for RateSelectionOffloadExtension
impl Default for RateSelectionOffloadExtension
Sourcefn default() -> RateSelectionOffloadExtension
fn default() -> RateSelectionOffloadExtension
Returns the “default value” for a type. Read more
Sourceimpl<'a, ___E> Encode<RateSelectionOffloadExtension<'static>, ___E> for &'a RateSelectionOffloadExtensionwhere
___E: Encoder + ?Sized,
impl<'a, ___E> Encode<RateSelectionOffloadExtension<'static>, ___E> for &'a RateSelectionOffloadExtensionwhere
___E: Encoder + ?Sized,
Sourcefn encode(
self,
encoder: &mut ___E,
out: &mut MaybeUninit<RateSelectionOffloadExtension<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder: &mut ___E, out: &mut MaybeUninit<RateSelectionOffloadExtension<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<RateSelectionOffloadExtension<'static>, ___E> for RateSelectionOffloadExtensionwhere
___E: Encoder + ?Sized,
impl<___E> Encode<RateSelectionOffloadExtension<'static>, ___E> for RateSelectionOffloadExtensionwhere
___E: Encoder + ?Sized,
Sourcefn encode(
self,
encoder: &mut ___E,
out: &mut MaybeUninit<RateSelectionOffloadExtension<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder: &mut ___E, out: &mut MaybeUninit<RateSelectionOffloadExtension<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'de> FromWire<RateSelectionOffloadExtension<'de>> for RateSelectionOffloadExtension
impl<'de> FromWire<RateSelectionOffloadExtension<'de>> for RateSelectionOffloadExtension
Sourcefn from_wire(
wire_: RateSelectionOffloadExtension<'de>,
) -> RateSelectionOffloadExtension
fn from_wire( wire_: RateSelectionOffloadExtension<'de>, ) -> RateSelectionOffloadExtension
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<RateSelectionOffloadExtension<'de>> for RateSelectionOffloadExtension
impl<'de> FromWireRef<RateSelectionOffloadExtension<'de>> for RateSelectionOffloadExtension
Sourcefn from_wire_ref(
wire: &RateSelectionOffloadExtension<'de>,
) -> RateSelectionOffloadExtension
fn from_wire_ref( wire: &RateSelectionOffloadExtension<'de>, ) -> RateSelectionOffloadExtension
Converts the given reference to this type.
Sourceimpl Hash for RateSelectionOffloadExtension
impl Hash for RateSelectionOffloadExtension
Sourceimpl Ord for RateSelectionOffloadExtension
impl Ord for RateSelectionOffloadExtension
Sourcefn cmp(&self, other: &RateSelectionOffloadExtension) -> Ordering
fn cmp(&self, other: &RateSelectionOffloadExtension) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for RateSelectionOffloadExtension
impl PartialEq for RateSelectionOffloadExtension
Sourcefn eq(&self, other: &RateSelectionOffloadExtension) -> bool
fn eq(&self, other: &RateSelectionOffloadExtension) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for RateSelectionOffloadExtension
impl PartialOrd for RateSelectionOffloadExtension
impl Copy for RateSelectionOffloadExtension
impl Eq for RateSelectionOffloadExtension
impl StructuralPartialEq for RateSelectionOffloadExtension