pub struct SaeFeature {
pub driver_handler_supported: Option<bool>,
pub sme_handler_supported: Option<bool>,
pub hash_to_element_supported: Option<bool>,
}Expand description
Simultaneous Authentication of Equals. See IEEE 802.11-2016 12.4. This is a security feature, usable for fullmac or softmac.
Fields
driver_handler_supported: Option<bool>sme_handler_supported: Option<bool>hash_to_element_supported: Option<bool>Trait Implementations
Sourceimpl Clone for SaeFeature
impl Clone for SaeFeature
Sourcefn clone(&self) -> SaeFeature
fn clone(&self) -> SaeFeature
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SaeFeature
impl Debug for SaeFeature
Sourceimpl Default for SaeFeature
impl Default for SaeFeature
Sourcefn default() -> SaeFeature
fn default() -> SaeFeature
Returns the “default value” for a type. Read more
Sourceimpl<'a, ___E> Encode<SaeFeature<'static>, ___E> for &'a SaeFeaturewhere
___E: Encoder + ?Sized,
impl<'a, ___E> Encode<SaeFeature<'static>, ___E> for &'a SaeFeaturewhere
___E: Encoder + ?Sized,
Sourcefn encode(
self,
encoder: &mut ___E,
out: &mut MaybeUninit<SaeFeature<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder: &mut ___E, out: &mut MaybeUninit<SaeFeature<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<SaeFeature<'static>, ___E> for SaeFeaturewhere
___E: Encoder + ?Sized,
impl<___E> Encode<SaeFeature<'static>, ___E> for SaeFeaturewhere
___E: Encoder + ?Sized,
Sourcefn encode(
self,
encoder: &mut ___E,
out: &mut MaybeUninit<SaeFeature<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder: &mut ___E, out: &mut MaybeUninit<SaeFeature<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'de> FromWire<SaeFeature<'de>> for SaeFeature
impl<'de> FromWire<SaeFeature<'de>> for SaeFeature
Sourcefn from_wire(wire_: SaeFeature<'de>) -> SaeFeature
fn from_wire(wire_: SaeFeature<'de>) -> SaeFeature
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<SaeFeature<'de>> for SaeFeature
impl<'de> FromWireRef<SaeFeature<'de>> for SaeFeature
Sourcefn from_wire_ref(wire: &SaeFeature<'de>) -> SaeFeature
fn from_wire_ref(wire: &SaeFeature<'de>) -> SaeFeature
Converts the given reference to this type.
Sourceimpl Hash for SaeFeature
impl Hash for SaeFeature
Sourceimpl Ord for SaeFeature
impl Ord for SaeFeature
Sourcefn cmp(&self, other: &SaeFeature) -> Ordering
fn cmp(&self, other: &SaeFeature) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for SaeFeature
impl PartialEq for SaeFeature
Sourcefn eq(&self, other: &SaeFeature) -> bool
fn eq(&self, other: &SaeFeature) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for SaeFeature
impl PartialOrd for SaeFeature
impl Copy for SaeFeature
impl Eq for SaeFeature
impl StructuralPartialEq for SaeFeature