pub struct ScheduledScanMatchSet {
pub ssid: Option<Vec<u8>>,
pub bssid: Option<[u8; 6]>,
pub min_rssi_threshold: Option<i8>,
pub relative_rssi_threshold: Option<i8>,
pub band_rssi_adjustments: Option<Vec<BandRssiAdjustment>>,
}Expand description
A nested set of attributes to match during scheduled scans. A BSS must meet ALL of the present criteria in the match set to be considered a match.
Since not all hardware supports matching all types of attributes, there is no guarantee that the reported BSSs are fully compliant with the match sets. A driver may return EINVAL if it cannot support a match set, or may ignore the match criteria.
Fields
ssid: Option<Vec<u8>>bssid: Option<[u8; 6]>min_rssi_threshold: Option<i8>relative_rssi_threshold: Option<i8>band_rssi_adjustments: Option<Vec<BandRssiAdjustment>>Trait Implementations
Sourceimpl Clone for ScheduledScanMatchSet
impl Clone for ScheduledScanMatchSet
Sourcefn clone(&self) -> ScheduledScanMatchSet
fn clone(&self) -> ScheduledScanMatchSet
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ScheduledScanMatchSet
impl Debug for ScheduledScanMatchSet
Sourceimpl Default for ScheduledScanMatchSet
impl Default for ScheduledScanMatchSet
Sourcefn default() -> ScheduledScanMatchSet
fn default() -> ScheduledScanMatchSet
Returns the “default value” for a type. Read more
Sourceimpl<'a, ___E> Encode<ScheduledScanMatchSet<'static>, ___E> for &'a ScheduledScanMatchSetwhere
___E: Encoder + ?Sized,
impl<'a, ___E> Encode<ScheduledScanMatchSet<'static>, ___E> for &'a ScheduledScanMatchSetwhere
___E: Encoder + ?Sized,
Sourcefn encode(
self,
encoder: &mut ___E,
out: &mut MaybeUninit<ScheduledScanMatchSet<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder: &mut ___E, out: &mut MaybeUninit<ScheduledScanMatchSet<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<ScheduledScanMatchSet<'static>, ___E> for ScheduledScanMatchSetwhere
___E: Encoder + ?Sized,
impl<___E> Encode<ScheduledScanMatchSet<'static>, ___E> for ScheduledScanMatchSetwhere
___E: Encoder + ?Sized,
Sourcefn encode(
self,
encoder: &mut ___E,
out: &mut MaybeUninit<ScheduledScanMatchSet<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder: &mut ___E, out: &mut MaybeUninit<ScheduledScanMatchSet<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'de> FromWire<ScheduledScanMatchSet<'de>> for ScheduledScanMatchSet
impl<'de> FromWire<ScheduledScanMatchSet<'de>> for ScheduledScanMatchSet
Sourcefn from_wire(wire_: ScheduledScanMatchSet<'de>) -> ScheduledScanMatchSet
fn from_wire(wire_: ScheduledScanMatchSet<'de>) -> ScheduledScanMatchSet
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<ScheduledScanMatchSet<'de>> for ScheduledScanMatchSet
impl<'de> FromWireRef<ScheduledScanMatchSet<'de>> for ScheduledScanMatchSet
Sourcefn from_wire_ref(wire: &ScheduledScanMatchSet<'de>) -> ScheduledScanMatchSet
fn from_wire_ref(wire: &ScheduledScanMatchSet<'de>) -> ScheduledScanMatchSet
Converts the given reference to this type.
Sourceimpl Hash for ScheduledScanMatchSet
impl Hash for ScheduledScanMatchSet
Sourceimpl Ord for ScheduledScanMatchSet
impl Ord for ScheduledScanMatchSet
Sourcefn cmp(&self, other: &ScheduledScanMatchSet) -> Ordering
fn cmp(&self, other: &ScheduledScanMatchSet) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ScheduledScanMatchSet
impl PartialEq for ScheduledScanMatchSet
Sourcefn eq(&self, other: &ScheduledScanMatchSet) -> bool
fn eq(&self, other: &ScheduledScanMatchSet) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for ScheduledScanMatchSet
impl PartialOrd for ScheduledScanMatchSet
impl Eq for ScheduledScanMatchSet
impl StructuralPartialEq for ScheduledScanMatchSet