pub struct WlanWmmParameters {
pub apsd: bool,
pub ac_be_params: WlanWmmAccessCategoryParameters,
pub ac_bk_params: WlanWmmAccessCategoryParameters,
pub ac_vi_params: WlanWmmAccessCategoryParameters,
pub ac_vo_params: WlanWmmAccessCategoryParameters,
}Fields
apsd: boolac_be_params: WlanWmmAccessCategoryParametersac_bk_params: WlanWmmAccessCategoryParametersac_vi_params: WlanWmmAccessCategoryParametersac_vo_params: WlanWmmAccessCategoryParametersTrait Implementations
Sourceimpl Clone for WlanWmmParameters
impl Clone for WlanWmmParameters
Sourcefn clone(&self) -> WlanWmmParameters
fn clone(&self) -> WlanWmmParameters
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for WlanWmmParameters
impl Debug for WlanWmmParameters
Sourceimpl<'a, ___E> Encode<WlanWmmParameters, ___E> for &'a WlanWmmParameterswhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<WlanWmmParameters, ___E> for &'a WlanWmmParameterswhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<WlanWmmParameters>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<WlanWmmParameters>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<WlanWmmParameters, ___E> for WlanWmmParameterswhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<WlanWmmParameters, ___E> for WlanWmmParameterswhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<WlanWmmParameters>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<WlanWmmParameters>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, WlanWmmParameters>, ___E> for &'a WlanWmmParameters
impl<'a, ___E> EncodeOption<Box<'static, WlanWmmParameters>, ___E> for &'a WlanWmmParameters
Sourcefn encode_option(
this: Option<&'a WlanWmmParameters>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, WlanWmmParameters>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a WlanWmmParameters>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, WlanWmmParameters>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, WlanWmmParameters>, ___E> for WlanWmmParameters
impl<___E> EncodeOption<Box<'static, WlanWmmParameters>, ___E> for WlanWmmParameters
Sourcefn encode_option(
this: Option<WlanWmmParameters>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, WlanWmmParameters>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<WlanWmmParameters>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, WlanWmmParameters>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<WlanWmmParameters> for WlanWmmParameters
impl FromWire<WlanWmmParameters> for WlanWmmParameters
Sourcefn from_wire(wire: WlanWmmParameters) -> WlanWmmParameters
fn from_wire(wire: WlanWmmParameters) -> WlanWmmParameters
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl FromWireRef<WlanWmmParameters> for WlanWmmParameters
impl FromWireRef<WlanWmmParameters> for WlanWmmParameters
Sourcefn from_wire_ref(wire: &WlanWmmParameters) -> WlanWmmParameters
fn from_wire_ref(wire: &WlanWmmParameters) -> WlanWmmParameters
Converts the given reference to this type.
Sourceimpl Hash for WlanWmmParameters
impl Hash for WlanWmmParameters
Sourceimpl Ord for WlanWmmParameters
impl Ord for WlanWmmParameters
Sourcefn cmp(&self, other: &WlanWmmParameters) -> Ordering
fn cmp(&self, other: &WlanWmmParameters) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for WlanWmmParameters
impl PartialEq for WlanWmmParameters
Sourcefn eq(&self, other: &WlanWmmParameters) -> bool
fn eq(&self, other: &WlanWmmParameters) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for WlanWmmParameters
impl PartialOrd for WlanWmmParameters
impl Copy for WlanWmmParameters
impl Eq for WlanWmmParameters
impl StructuralPartialEq for WlanWmmParameters