pub struct OweFeature {
pub supported: Option<bool>,
}Expand description
Opportunistic Wireless Encryption. See RFC 8110. This is a security feature, usable for fullmac or softmac.
Fields
supported: Option<bool>Trait Implementations
Sourceimpl Clone for OweFeature
impl Clone for OweFeature
Sourcefn clone(&self) -> OweFeature
fn clone(&self) -> OweFeature
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for OweFeature
impl Debug for OweFeature
Sourceimpl Default for OweFeature
impl Default for OweFeature
Sourcefn default() -> OweFeature
fn default() -> OweFeature
Returns the “default value” for a type. Read more
Sourceimpl<'a, ___E> Encode<OweFeature<'static>, ___E> for &'a OweFeaturewhere
___E: Encoder + ?Sized,
impl<'a, ___E> Encode<OweFeature<'static>, ___E> for &'a OweFeaturewhere
___E: Encoder + ?Sized,
Sourcefn encode(
self,
encoder: &mut ___E,
out: &mut MaybeUninit<OweFeature<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder: &mut ___E, out: &mut MaybeUninit<OweFeature<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<OweFeature<'static>, ___E> for OweFeaturewhere
___E: Encoder + ?Sized,
impl<___E> Encode<OweFeature<'static>, ___E> for OweFeaturewhere
___E: Encoder + ?Sized,
Sourcefn encode(
self,
encoder: &mut ___E,
out: &mut MaybeUninit<OweFeature<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder: &mut ___E, out: &mut MaybeUninit<OweFeature<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'de> FromWire<OweFeature<'de>> for OweFeature
impl<'de> FromWire<OweFeature<'de>> for OweFeature
Sourcefn from_wire(wire_: OweFeature<'de>) -> OweFeature
fn from_wire(wire_: OweFeature<'de>) -> OweFeature
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<OweFeature<'de>> for OweFeature
impl<'de> FromWireRef<OweFeature<'de>> for OweFeature
Sourcefn from_wire_ref(wire: &OweFeature<'de>) -> OweFeature
fn from_wire_ref(wire: &OweFeature<'de>) -> OweFeature
Converts the given reference to this type.
Sourceimpl Hash for OweFeature
impl Hash for OweFeature
Sourceimpl Ord for OweFeature
impl Ord for OweFeature
Sourcefn cmp(&self, other: &OweFeature) -> Ordering
fn cmp(&self, other: &OweFeature) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for OweFeature
impl PartialEq for OweFeature
Sourcefn eq(&self, other: &OweFeature) -> bool
fn eq(&self, other: &OweFeature) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for OweFeature
impl PartialOrd for OweFeature
impl Copy for OweFeature
impl Eq for OweFeature
impl StructuralPartialEq for OweFeature