pub struct ScanOffloadExtension {
pub supported: Option<bool>,
pub scan_cancel_supported: Option<bool>,
}Expand description
Indicates where and how scan logic is orchestrated. See IEEE 802.11-2016 11.1.4.2 and 11.1.4.3. This is a discovery extension, expected to be used for softmac only.
Fields
supported: Option<bool>scan_cancel_supported: Option<bool>Trait Implementations
Sourceimpl Clone for ScanOffloadExtension
impl Clone for ScanOffloadExtension
Sourcefn clone(&self) -> ScanOffloadExtension
fn clone(&self) -> ScanOffloadExtension
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ScanOffloadExtension
impl Debug for ScanOffloadExtension
Sourceimpl Default for ScanOffloadExtension
impl Default for ScanOffloadExtension
Sourcefn default() -> ScanOffloadExtension
fn default() -> ScanOffloadExtension
Returns the “default value” for a type. Read more
Sourceimpl<'a, ___E> Encode<ScanOffloadExtension<'static>, ___E> for &'a ScanOffloadExtensionwhere
___E: Encoder + ?Sized,
impl<'a, ___E> Encode<ScanOffloadExtension<'static>, ___E> for &'a ScanOffloadExtensionwhere
___E: Encoder + ?Sized,
Sourcefn encode(
self,
encoder: &mut ___E,
out: &mut MaybeUninit<ScanOffloadExtension<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder: &mut ___E, out: &mut MaybeUninit<ScanOffloadExtension<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<ScanOffloadExtension<'static>, ___E> for ScanOffloadExtensionwhere
___E: Encoder + ?Sized,
impl<___E> Encode<ScanOffloadExtension<'static>, ___E> for ScanOffloadExtensionwhere
___E: Encoder + ?Sized,
Sourcefn encode(
self,
encoder: &mut ___E,
out: &mut MaybeUninit<ScanOffloadExtension<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder: &mut ___E, out: &mut MaybeUninit<ScanOffloadExtension<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'de> FromWire<ScanOffloadExtension<'de>> for ScanOffloadExtension
impl<'de> FromWire<ScanOffloadExtension<'de>> for ScanOffloadExtension
Sourcefn from_wire(wire_: ScanOffloadExtension<'de>) -> ScanOffloadExtension
fn from_wire(wire_: ScanOffloadExtension<'de>) -> ScanOffloadExtension
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<ScanOffloadExtension<'de>> for ScanOffloadExtension
impl<'de> FromWireRef<ScanOffloadExtension<'de>> for ScanOffloadExtension
Sourcefn from_wire_ref(wire: &ScanOffloadExtension<'de>) -> ScanOffloadExtension
fn from_wire_ref(wire: &ScanOffloadExtension<'de>) -> ScanOffloadExtension
Converts the given reference to this type.
Sourceimpl Hash for ScanOffloadExtension
impl Hash for ScanOffloadExtension
Sourceimpl Ord for ScanOffloadExtension
impl Ord for ScanOffloadExtension
Sourcefn cmp(&self, other: &ScanOffloadExtension) -> Ordering
fn cmp(&self, other: &ScanOffloadExtension) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ScanOffloadExtension
impl PartialEq for ScanOffloadExtension
Sourcefn eq(&self, other: &ScanOffloadExtension) -> bool
fn eq(&self, other: &ScanOffloadExtension) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for ScanOffloadExtension
impl PartialOrd for ScanOffloadExtension
impl Copy for ScanOffloadExtension
impl Eq for ScanOffloadExtension
impl StructuralPartialEq for ScanOffloadExtension