#[repr(C)]pub struct ScheduledScanPlan {
pub interval: Uint32,
pub iterations: Uint32,
}Expand description
The wire type corresponding to ScheduledScanPlan.
Fields
interval: Uint32iterations: Uint32Trait Implementations
Sourceimpl Clone for ScheduledScanPlan
impl Clone for ScheduledScanPlan
Sourcefn clone(&self) -> ScheduledScanPlan
fn clone(&self) -> ScheduledScanPlan
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for ScheduledScanPlan
impl Constrained for ScheduledScanPlan
Sourcetype Constraint = ()
type Constraint = ()
Type of constraint information for this type.
Sourcefn validate(
_: Slot<'_, ScheduledScanPlan>,
_: <ScheduledScanPlan as Constrained>::Constraint,
) -> Result<(), ValidationError>
fn validate( _: Slot<'_, ScheduledScanPlan>, _: <ScheduledScanPlan as Constrained>::Constraint, ) -> Result<(), ValidationError>
Validate a slot of this type against a constraint. Can be called when
pointers/envelopes are just presence markers.
Sourceimpl Debug for ScheduledScanPlan
impl Debug for ScheduledScanPlan
Sourceimpl<___D> Decode<___D> for ScheduledScanPlanwhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for ScheduledScanPlanwhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<ScheduledScanPlan, ___E> for &'a ScheduledScanPlanwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<ScheduledScanPlan, ___E> for &'a ScheduledScanPlanwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ScheduledScanPlan>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ScheduledScanPlan>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<ScheduledScanPlan, ___E> for ScheduledScanPlanwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<ScheduledScanPlan, ___E> for ScheduledScanPlanwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<ScheduledScanPlan, ScheduledScanPlan>
const COPY_OPTIMIZATION: CopyOptimization<ScheduledScanPlan, ScheduledScanPlan>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ScheduledScanPlan>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ScheduledScanPlan>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0, T1> Encode<ScheduledScanPlan, ___E> for ScheduledScanPlan<T0, T1>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Uint32, ___E>,
T1: Encode<Uint32, ___E>,
impl<___E, T0, T1> Encode<ScheduledScanPlan, ___E> for ScheduledScanPlan<T0, T1>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Uint32, ___E>,
T1: Encode<Uint32, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ScheduledScanPlan>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ScheduledScanPlan>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<ScheduledScanPlan> for ScheduledScanPlan
impl FromWire<ScheduledScanPlan> for ScheduledScanPlan
Sourceconst COPY_OPTIMIZATION: CopyOptimization<ScheduledScanPlan, ScheduledScanPlan>
const COPY_OPTIMIZATION: CopyOptimization<ScheduledScanPlan, ScheduledScanPlan>
Sourcefn from_wire(wire: ScheduledScanPlan) -> ScheduledScanPlan
fn from_wire(wire: ScheduledScanPlan) -> ScheduledScanPlan
Converts the given owned value to this type.
Sourceimpl FromWireRef<ScheduledScanPlan> for ScheduledScanPlan
impl FromWireRef<ScheduledScanPlan> for ScheduledScanPlan
Sourcefn from_wire_ref(wire: &ScheduledScanPlan) -> ScheduledScanPlan
fn from_wire_ref(wire: &ScheduledScanPlan) -> ScheduledScanPlan
Converts the given reference to this type.
Sourceimpl IntoNatural for ScheduledScanPlan
impl IntoNatural for ScheduledScanPlan
Sourcetype Natural = ScheduledScanPlan
type Natural = ScheduledScanPlan
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for ScheduledScanPlan
impl Wire for ScheduledScanPlan
Sourcetype Narrowed<'de> = ScheduledScanPlan
type Narrowed<'de> = ScheduledScanPlan
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<ScheduledScanPlan>)
fn zero_padding(out_: &mut MaybeUninit<ScheduledScanPlan>)
Writes zeroes to the padding for this type, if any.