#[repr(C)]pub struct WlanTxResult {
pub tx_result_entry: [WlanTxResultEntry; 8],
pub peer_addr: [u8; 6],
pub result_code: WlanTxResultCode,
}Expand description
The wire type corresponding to WlanTxResult.
Fields
tx_result_entry: [WlanTxResultEntry; 8]peer_addr: [u8; 6]result_code: WlanTxResultCodeTrait Implementations
Sourceimpl Clone for WlanTxResult
impl Clone for WlanTxResult
Sourcefn clone(&self) -> WlanTxResult
fn clone(&self) -> WlanTxResult
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for WlanTxResult
impl Constrained for WlanTxResult
Sourcetype Constraint = ()
type Constraint = ()
Type of constraint information for this type.
Sourcefn validate(
_: Slot<'_, WlanTxResult>,
_: <WlanTxResult as Constrained>::Constraint,
) -> Result<(), ValidationError>
fn validate( _: Slot<'_, WlanTxResult>, _: <WlanTxResult as Constrained>::Constraint, ) -> Result<(), ValidationError>
Validate a slot of this type against a constraint. Can be called when
pointers/envelopes are just presence markers.
Sourceimpl Debug for WlanTxResult
impl Debug for WlanTxResult
Sourceimpl<___D> Decode<___D> for WlanTxResultwhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for WlanTxResultwhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<WlanTxResult, ___E> for &'a WlanTxResultwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<WlanTxResult, ___E> for &'a WlanTxResultwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<WlanTxResult>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<WlanTxResult>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<WlanTxResult, ___E> for WlanTxResultwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<WlanTxResult, ___E> for WlanTxResultwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<WlanTxResult>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<WlanTxResult>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E, T0, T1, T2> Encode<WlanTxResult, ___E> for WlanTxResult<T0, T1, T2>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<[WlanTxResultEntry; 8], ___E>,
T1: Encode<[u8; 6], ___E>,
T2: Encode<WlanTxResultCode, ___E>,
impl<___E, T0, T1, T2> Encode<WlanTxResult, ___E> for WlanTxResult<T0, T1, T2>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<[WlanTxResultEntry; 8], ___E>,
T1: Encode<[u8; 6], ___E>,
T2: Encode<WlanTxResultCode, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<WlanTxResult>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<WlanTxResult>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<WlanTxResult> for WlanTxResult
impl FromWire<WlanTxResult> for WlanTxResult
Sourcefn from_wire(wire: WlanTxResult) -> WlanTxResult
fn from_wire(wire: WlanTxResult) -> WlanTxResult
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl FromWireRef<WlanTxResult> for WlanTxResult
impl FromWireRef<WlanTxResult> for WlanTxResult
Sourcefn from_wire_ref(wire: &WlanTxResult) -> WlanTxResult
fn from_wire_ref(wire: &WlanTxResult) -> WlanTxResult
Converts the given reference to this type.
Sourceimpl IntoNatural for WlanTxResult
impl IntoNatural for WlanTxResult
Sourcetype Natural = WlanTxResult
type Natural = WlanTxResult
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for WlanTxResult
impl Wire for WlanTxResult
Sourcetype Narrowed<'de> = WlanTxResult
type Narrowed<'de> = WlanTxResult
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<WlanTxResult>)
fn zero_padding(out_: &mut MaybeUninit<WlanTxResult>)
Writes zeroes to the padding for this type, if any.